pilas.escenas.Normal

Package pilas :: Module escenas :: Class Normal |
[hide private]
[frames] | no frames]

# Class Normal

source code

    object --+
             |
        Escena --+
                 |
                Normal

Representa la escena inicial mas simple.

Instance Methods | [hide private]
__init__(self, color_de_fondo=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
Inherited from `Escena`: `iniciar`, `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, color_de_fondo=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)